==> v0.1.tar.gz: szczanieckiej/config/config.go <==
package config

import (
	"bufio"
	"os"
	"strings"

	"notabug.org/apiote/gott"
)

// todo change to dirty

type Config struct {
	FeedsPath    string
	AdminContact string
	RateLimited  bool
	Private      bool
	EnabledFeeds []string
}

type result struct {
	configPath string
	configFile *os.File
	config     Config
}

func openFile(input ...interface{}) (interface{}, error) {
	args := input[0].(result)
	configFile, err := os.Open(args.configPath)
	args.configFile = configFile
	return gott.Tuple{args}, err
}

func scan(input ...interface{}) interface{} {
	args := input[0].(result)
	configFile := args.configFile
	config := args.config

	scanner := bufio.NewScanner(configFile)
	for scanner.Scan() {
		line := scanner.Text()
		if line == "" || line[0] == '#' {
			continue
		}
		assignment := strings.Split(line, "=")
		key := strings.Trim(assignment[0], " ")
		value := strings.Trim(assignment[1], " ")
		if key == "feeds_path" {
			config.FeedsPath = strings.ReplaceAll(value, "\"", "")
		}
		if key == "enabled_feeds" {
			value = strings.Replace(strings.Replace(value, "[", "", 1), "]", "", 1)
			elements := strings.Split(value, ",")
			for _, e := range elements {
				e = strings.ReplaceAll(strings.Trim(e, " "), "\"", "")
				config.EnabledFeeds = append(config.EnabledFeeds, e)
			}
		}
		if key == "admin_contact" {
			config.AdminContact = strings.ReplaceAll(value, "\"", "")
		}
		if key == "rate_limited" {
			config.RateLimited = value == "true"
		}
		if key == "private" {
			config.Private = value == "true"
		}
	}
	args.config = config

	configFile.Close()

	return gott.Tuple{args}
}

func Read(configPath string) (Config, error) {
	input := gott.Tuple{result{
		configPath: configPath,
		config:     Config{EnabledFeeds: []string{}},
	}}
	output, err := gott.NewResult(input).
		Bind(openFile).
		Map(scan).
		Finish()
	if err != nil {
		return Config{}, err
	}
	return output.(gott.Tuple)[0].(result).config, nil
}

==> v0.2.tar.gz: szczanieckiej/config/config.go <==
package config

import (
	"bufio"
	"os"
	"strings"

	"notabug.org/apiote/gott"
)

// todo change to dirty

type Config struct {
	FeedsPath     string
	EnabledFeeds  []string
	ListenAddress string
}

type result struct {
	configPath string
	configFile *os.File
	config     Config
}

func openFile(input ...interface{}) (interface{}, error) {
	args := input[0].(result)
	configFile, err := os.Open(args.configPath)
	args.configFile = configFile
	return gott.Tuple{args}, err
}

func scan(input ...interface{}) interface{} {
	args := input[0].(result)
	configFile := args.configFile
	config := args.config

	scanner := bufio.NewScanner(configFile)
	for scanner.Scan() {
		line := scanner.Text()
		if line == "" || line[0] == '#' {
			continue
		}
		assignment := strings.Split(line, "=")
		key := strings.Trim(assignment[0], " ")
		value := strings.Trim(assignment[1], " ")
		if key == "feeds_path" {
			config.FeedsPath = strings.ReplaceAll(value, "\"", "")
		}
		if key == "enabled_feeds" {
			value = strings.Replace(strings.Replace(value, "[", "", 1), "]", "", 1)
			elements := strings.Split(value, ",")
			for _, e := range elements {
				e = strings.ReplaceAll(strings.Trim(e, " "), "\"", "")
				config.EnabledFeeds = append(config.EnabledFeeds, e)
			}
		}
		if key == "listen_address" {
			config.ListenAddress = strings.ReplaceAll(value, "\"", "")
		}
	}
	args.config = config

	configFile.Close()

	return gott.Tuple{args}
}

func Read(configPath string) (Config, error) {
	input := gott.Tuple{
		result{
			configPath: configPath,
			config: Config{
				EnabledFeeds:  []string{},
				FeedsPath:     "/var/lib/szczanieckiej",
				ListenAddress: ":51354",
			},
		},
	}
	output, err := gott.NewResult(input).
		Bind(openFile).
		Map(scan).
		Finish()
	if err != nil {
		return Config{}, err
	}
	return output.(gott.Tuple)[0].(result).config, nil
}
